@@ -6,9 +6,7 @@
  * @see {@link https://docs.python.org/3/reference/grammar.html|Python 3 grammar}
  */
 
-/* eslint-disable arrow-parens */
-/* eslint-disable camelcase */
-/* eslint-disable-next-line spaced-comment */
+
 /// <reference types="tree-sitter-cli/dsl" />
 // @ts-check
 
@@ -361,10 +359,10 @@ module.exports = grammar({
     except_clause: $ => seq(
       'except',
       optional(seq(
-        $.expression,
+        field('value', $.expression),
         optional(seq(
           choice('as', ','),
-          $.expression,
+          field('alias', $.expression),
         )),
       )),
       ':',
@@ -464,9 +462,9 @@ module.exports = grammar({
 
     type_alias_statement: $ => prec.dynamic(1, seq(
       'type',
-      $.type,
+      field('left', $.type),
       '=',
-      $.type,
+      field('right', $.type),
     )),
 
     class_definition: $ => seq(
@@ -945,7 +943,7 @@ module.exports = grammar({
     )),
 
     type: $ => choice(
-      $.expression,
+      prec(1, $.expression),
       $.splat_type,
       $.generic_type,
       $.union_type,
@@ -953,7 +951,13 @@ module.exports = grammar({
       $.member_type,
     ),
     splat_type: $ => prec(1, seq(choice('*', '**'), $.identifier)),
-    generic_type: $ => prec(1, seq($.identifier, $.type_parameter)),
+    generic_type: $ => prec(1, seq(
+      choice(
+        $.identifier,
+        alias('type', $.identifier),
+      ),
+      $.type_parameter,
+    )),
     union_type: $ => prec.left(seq($.type, '|', $.type)),
     constrained_type: $ => prec.right(seq($.type, ':', $.type)),
     member_type: $ => seq($.type, '.', $.identifier),
@@ -1210,8 +1214,7 @@ module.exports.PREC = PREC;
  *
  * @param {RuleOrLiteral} rule
  *
- * @return {SeqRule}
- *
+ * @returns {SeqRule}
  */
 function commaSep1(rule) {
   return sep1(rule, ',');
@@ -1224,8 +1227,7 @@ function commaSep1(rule) {
  *
  * @param {RuleOrLiteral} separator
  *
- * @return {SeqRule}
- *
+ * @returns {SeqRule}
  */
 function sep1(rule, separator) {
   return seq(rule, repeat(seq(separator, rule)));
